<?xml version="1.0" encoding="utf-8"?><!DOCTYPE TS><TS language="cy" sourcelanguage="en" version="2.0">
<context>
    <name>AboutDialogBase</name>
    <message>
        <location filename="res/AboutDialogBase.ui" line="38"/>
        <source>About Synergy</source>
        <translation type="finished">Ynghylch Synergy</translation>
    </message>
    <message utf8="true">
        <location filename="res/AboutDialogBase.ui" line="53"/>
        <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012 Bolton Software Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (synergy-foss.org).
&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012 Bolton Software Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (synergy-foss.org).
&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="140"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="124"/>
        <source>Version:</source>
        <translation type="finished">Fersiwn:</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="163"/>
        <source>&amp;Ok</source>
        <translation type="finished">Iawn</translation>
    </message>
</context>
<context>
    <name>ActionDialogBase</name>
    <message>
        <location filename="res/ActionDialogBase.ui" line="14"/>
        <source>Configure Action</source>
        <translation type="finished">Cyflunio Gweithred</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="20"/>
        <source>Choose the action to perform</source>
        <translation type="finished">Dewiswch y weithred i wneud</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="26"/>
        <source>Press a hotkey</source>
        <translation type="finished">Gwasgwch fysell brys</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="36"/>
        <source>Release a hotkey</source>
        <translation type="finished">Ryddhewch y bysell frys</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="43"/>
        <source>Press and release a hotkey</source>
        <translation type="finished">Gwasgwch a ryddhewch y bysell frys</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="69"/>
        <source>only on these screens</source>
        <translation type="finished">ar y sgriniau yma yn unig</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="119"/>
        <source>Switch to screen</source>
        <translation type="finished">Newid i sgrîn</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="150"/>
        <source>Switch in direction</source>
        <translation type="finished">Newid cyfeiriad</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="174"/>
        <source>left</source>
        <translation type="finished">chwith</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="179"/>
        <source>right</source>
        <translation type="finished">dde</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="184"/>
        <source>up</source>
        <translation type="finished">fyny</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="189"/>
        <source>down</source>
        <translation type="finished">lawr</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="201"/>
        <source>Lock cursor to screen</source>
        <translation type="finished">Cloi cyrchydd i'r sgrîn</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="225"/>
        <source>toggle</source>
        <translation type="finished">toglo</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="230"/>
        <source>on</source>
        <translation type="finished">ymlaen</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="235"/>
        <source>off</source>
        <translation type="finished">i ffwrdd</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="248"/>
        <source>This action is performed when</source>
        <translation type="finished">Mae'r weithred hwn yn cael ei wneud gan</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="254"/>
        <source>the hotkey is pressed</source>
        <translation type="finished">pan wasgir y bysell frys</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="264"/>
        <source>the hotkey is released</source>
        <translation type="finished">pan ryddheir y bysell frys</translation>
    </message>
</context>
<context>
    <name>HotkeyDialogBase</name>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="14"/>
        <source>Hotkey</source>
        <translation type="finished">Bysell frys</translation>
    </message>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="20"/>
        <source>Enter the specification for the hotkey:</source>
        <translation type="finished">Rhowch y manyleb ar gyfer y bysell frws hwn:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="642"/>
        <source>&amp;Start</source>
        <translation type="finished">Dechrau</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="196"/>
        <source>&amp;File</source>
        <translation type="finished">Ffeil</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="197"/>
        <source>&amp;Edit</source>
        <translation type="finished">Golygu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="198"/>
        <source>&amp;Window</source>
        <translation type="finished">Ffenest</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="199"/>
        <source>&amp;Help</source>
        <translation type="finished">Cymorth</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="326"/>
        <source>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</source>
        <translation type="finished">&lt;p&gt;Mae fersiwn %1 ar gael nawr, &lt;a href=&quot;%2&quot;&gt;ymwelwch a'r wefan&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>Program can not be started</source>
        <translation type="finished">Methwyd cychwyn y rhaglen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
        <translation type="finished">Nid oedd yn bosib cychwyn y rhaglen &lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;yn llwyddiannus er ei fod yn bodoli. Gwnewch yn siwr fod ganddoch yr hawliau cywir i redeg y rhaglen yma.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="477"/>
        <source>Synergy client not found</source>
        <translation type="finished">Methwyd dod o hyd i gleient Synergy</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="478"/>
        <source>The executable for the synergy client does not exist.</source>
        <translation type="finished">Nid yw'r ffeil weithredadwy ar gyfer y cleient synergy yn bodoli.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="485"/>
        <source>Hostname is empty</source>
        <translation type="finished">Mae'r enw gwesteiwr yn bodoli</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="486"/>
        <source>Please fill in a hostname for the synergy client to connect to.</source>
        <translation type="finished">Rhowch enw gwesteiwr i'r cleient synergy i gysylltu iddo.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="511"/>
        <source>Cannot write configuration file</source>
        <translation type="finished">Methu sgrifennu i'r ffeil gyfluniad</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="511"/>
        <source>The temporary configuration file required to start synergy can not be written.</source>
        <translation type="finished">Nid yw'n bosib sgrifennu i'r ffeil gyfluniad dros dro sydd angen i ddechrau synergy</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="524"/>
        <source>Configuration filename invalid</source>
        <translation type="finished">Mae enw'r ffeil gyfluniad yn annilys</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="525"/>
        <source>You have not filled in a valid configuration file for the synergy server. Do you want to browse for the configuration file now?</source>
        <translation type="finished">Nid ydych wedi llenwi mewn ffeil gyfluniad dilys ar gyfer y gweinydd synergy. Hoffech chi bori am ffeil gyfluniad nawr?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="552"/>
        <source>Synergy server not found</source>
        <translation type="finished">Methwyd dod o hyd i weinydd Synergy</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="553"/>
        <source>The executable for the synergy server does not exist.</source>
        <translation type="finished">Nid yw'r ffeil weithredadwy ar gyfer y gweinydd synergy yn bodoli.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="617"/>
        <source>Synergy terminated with an error</source>
        <translation type="finished">Fe wnaeth Synergy derfynnu gyda gwall</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="617"/>
        <source>Synergy terminated unexpectedly with an exit code of %1.&lt;br&gt;&lt;br&gt;Please see the log output for details.</source>
        <translation type="finished">Fe wnaeth Synergy derfynnu yn annisgwyl gyda cod gorffen %1.&lt;br&gt;&lt;br&gt;Gwelwch allbwn log am fanylion.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="636"/>
        <source>&amp;Stop</source>
        <translation type="finished">Stopio</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="659"/>
        <source>service mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="659"/>
        <source>desktop mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="660"/>
        <source>Synergy is running (%1).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="821"/>
        <source>Elevate Synergy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="822"/>
        <source>Are you sure you want to elevate Synergy?

This allows Synergy to interact with elevated processes and the UAC dialog, but can cause problems with non-elevated processes. Elevate Synergy only if you really need to.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="664"/>
        <source>Synergy is starting.</source>
        <translation type="finished">Mae Synergy yn dechrau.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="667"/>
        <source>Synergy is not running.</source>
        <translation type="finished">Nid yw Synergy yn rhedeg.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="724"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="762"/>
        <source>Browse for a synergys config file</source>
        <translation type="finished">Profi am ffeil gyfluniad synergys</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="775"/>
        <source>Save configuration as...</source>
        <translation type="finished">Cadw'r cyfluniad fel...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="779"/>
        <source>Save failed</source>
        <translation type="finished">Methwyd cadw</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="779"/>
        <source>Could not save configuration to file.</source>
        <translation type="finished">Methwyd cadw'r ffeil gyfluniad</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <location filename="res/MainWindowBase.ui" line="26"/>
        <source>Synergy</source>
        <translation type="finished">Synergy</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="54"/>
        <source>Screen name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="61"/>
        <source>&amp;Server IP:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="160"/>
        <location filename="res/MainWindowBase.ui" line="315"/>
        <source>&amp;Start</source>
        <translation type="finished">Dechrau</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="187"/>
        <source>&amp;Server (share this computer's mouse and keyboard):</source>
        <translation type="finished">Gweinydd (rhannu bysellfwrdd a llygoden y cyfrifiadur hwn).</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="254"/>
        <source>Use existing configuration:</source>
        <translation type="finished">Defnyddio'r cyfluniad presennol:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="263"/>
        <source>&amp;Configuration file:</source>
        <translation type="finished">Ffeil Cyfluniad:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="283"/>
        <source>&amp;Browse...</source>
        <translation type="finished">Pori...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="220"/>
        <source>Configure interactively:</source>
        <translation type="finished">Cyflunio'n rhyngweithiol:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="232"/>
        <source>&amp;Configure Server...</source>
        <translation type="finished">Cyflunio Gweinydd...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="39"/>
        <source>&amp;Client (use another computer's keyboard and mouse):</source>
        <translation type="finished">Cleient (defnyddio bysellfwrdd a llygoden cyfrifiadur arall):</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="84"/>
        <source>Ready</source>
        <translation type="finished">Yn barod</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="91"/>
        <source>Log</source>
        <translation type="finished">Log</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="167"/>
        <source>&amp;Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="174"/>
        <source>&amp;Elevate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="204"/>
        <source>IP addresses:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="296"/>
        <source>&amp;About Synergy...</source>
        <translation type="finished">Ynghylch Synergy</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="304"/>
        <source>&amp;Quit</source>
        <translation type="finished">Gadael</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="307"/>
        <source>Quit</source>
        <translation type="finished">Gadael</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="318"/>
        <source>Run</source>
        <translation type="finished">Rhedeg</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="329"/>
        <source>S&amp;top</source>
        <translation type="finished">Stopio</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="332"/>
        <source>Stop</source>
        <translation type="finished">Stopop</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="340"/>
        <source>S&amp;how Status</source>
        <translation type="finished">Dangos Statws</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="348"/>
        <source>&amp;Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="351"/>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="359"/>
        <source>&amp;Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="362"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="370"/>
        <source>Save configuration &amp;as...</source>
        <translation type="finished">Cadw'r cyfluniad fel...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="373"/>
        <source>Save the interactively generated server configuration to a file.</source>
        <translation type="finished">Cadw'r cyfluniad gweinydd a gynhyrchwyd i ffeil:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="381"/>
        <source>Settings</source>
        <translation type="finished">Gosodiadau</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="384"/>
        <source>Edit settings</source>
        <translation type="finished">Golygu gosodiadau</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="392"/>
        <source>Run Wizard</source>
        <translation type="finished">Rhedeg Dewin</translation>
    </message>
</context>
<context>
    <name>NewScreenWidget</name>
    <message>
        <location filename="src/NewScreenWidget.cpp" line="32"/>
        <source>Unnamed</source>
        <translation type="finished">Heb ei enwi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="src/MainWindow.cpp" line="45"/>
        <source>Synergy Configurations (*.sgc);;All files (*.*)</source>
        <translation type="finished">Cyfluniadau Synergy (*.sgc);;Pob ffeil (*.*)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="48"/>
        <source>Synergy Configurations (*.conf);;All files (*.*)</source>
        <translation type="finished">Cyfluniadau Synergy (*.conf);;Pob ffeil (*.*)</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="90"/>
        <source>System tray is unavailable, quitting.</source>
        <translation type="finished">Nid yw'r gilfach system ar gael, yn gadael.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialog</name>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="65"/>
        <source>Screen name is empty</source>
        <translation type="finished">Mae enw'r sgrîn yn wag</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="65"/>
        <source>The name for a screen can not be empty. Please fill in a name or cancel the dialog.</source>
        <translation type="finished">Ni all enw'r sgrîn fod yn wag. Rhowch enw neu ganslo'r ddeialog.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialogBase</name>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="14"/>
        <source>Screen Settings</source>
        <translation type="finished">Gosodiadau Sgrîn</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="22"/>
        <source>Screen &amp;name:</source>
        <translation type="finished">Enw sgrîn</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="42"/>
        <source>A&amp;liases</source>
        <translation type="finished">Ffugenwau</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="57"/>
        <source>&amp;Add</source>
        <translation type="finished">Ychwanegu</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="74"/>
        <source>&amp;Remove</source>
        <translation type="finished">Dileu</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="97"/>
        <source>&amp;Modifier keys</source>
        <translation type="finished">Bysellau newid</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="106"/>
        <source>&amp;Shift:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="117"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="164"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="211"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="258"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="305"/>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="122"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="169"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="216"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="263"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="310"/>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="127"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="174"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="221"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="268"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="315"/>
        <source>Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="132"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="179"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="226"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="273"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="320"/>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="137"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="184"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="231"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="278"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="325"/>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="142"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="189"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="236"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="283"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="330"/>
        <source>None</source>
        <translation type="finished">Dim</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="150"/>
        <source>&amp;Ctrl:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="197"/>
        <source>Al&amp;t:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="244"/>
        <source>M&amp;eta:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="291"/>
        <source>S&amp;uper:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="358"/>
        <source>&amp;Dead corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="367"/>
        <source>Top-left</source>
        <translation type="finished">Top-chwith</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="374"/>
        <source>Top-right</source>
        <translation type="finished">Top-dde</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="381"/>
        <source>Bottom-left</source>
        <translation type="finished">Gwaelod-chwith</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="388"/>
        <source>Bottom-right</source>
        <translation type="finished">Gwaelod-dde</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="397"/>
        <source>Corner Si&amp;ze:</source>
        <translation type="finished">Maint Cornel:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="428"/>
        <source>&amp;Fixes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="437"/>
        <source>Fix CAPS LOCK key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="444"/>
        <source>Fix NUM LOCK key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="451"/>
        <source>Fix SCROLL LOCK key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="458"/>
        <source>Fix XTest for Xinerama</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenSetupModel</name>
    <message>
        <location filename="src/ScreenSetupModel.cpp" line="51"/>
        <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerConfigDialogBase</name>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="13"/>
        <source>Server Configuration</source>
        <translation type="finished">Cyfluniad Gweinydd</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="23"/>
        <source>Screens and links</source>
        <translation type="finished">Sgriniau a dolenni</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="34"/>
        <source>Drag a screen from the grid to the trashcan to remove it.</source>
        <translation type="finished">Llusgwch sgrîn o'r grid neu i'r bin sbwriel i'w ddileu.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="59"/>
        <source>Configure the layout of your synergy server configuration.</source>
        <translation type="finished">Cyfluniwch gynllun eich cyfluniad gweinydd synergy</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="72"/>
        <source>Drag this button to the grid to add a new screen.</source>
        <translation type="finished">Llusgwch y botwm i'r grid i ychwanegu sgrîn newydd.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="127"/>
        <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
        <translation type="finished">Llusgwch sgrîn newydd i'r grid neu symudwch y rhai presennol o gwmpas.
Llusgwch sgrîn i'r bin sbwriel i'w ddileu.
Rhowch glic dwbl ar sgrîn i newid ei osodiadau.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="156"/>
        <source>Hotkeys</source>
        <translation type="finished">Bysellau brys</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="162"/>
        <source>&amp;Hotkeys</source>
        <translation type="finished">Bysellau brys</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="174"/>
        <source>&amp;New</source>
        <translation type="finished">Newydd</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="184"/>
        <source>&amp;Edit</source>
        <translation type="finished">Golygu</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="194"/>
        <source>&amp;Remove</source>
        <translation type="finished">Dileu</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="217"/>
        <source>A&amp;ctions</source>
        <translation type="finished">Gweithredoedd</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="229"/>
        <source>Ne&amp;w</source>
        <translation type="finished">Newydd</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="239"/>
        <source>E&amp;dit</source>
        <translation type="finished">Golygu</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="249"/>
        <source>Re&amp;move</source>
        <translation type="finished">Dileu</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="273"/>
        <source>Advanced server settings</source>
        <translation type="finished">Gosodiadau uwch y gweinydd</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="279"/>
        <source>&amp;Switch</source>
        <translation type="finished">Newid</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="290"/>
        <source>Switch &amp;after waiting</source>
        <translation type="finished">Newid ar ôl aros</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="329"/>
        <location filename="res/ServerConfigDialogBase.ui" line="382"/>
        <location filename="res/ServerConfigDialogBase.ui" line="457"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="343"/>
        <source>Switch on double &amp;tap within</source>
        <translation type="finished">Newid ar ôl tap dwl yn</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="407"/>
        <source>&amp;Options</source>
        <translation type="finished">Dewisiadau</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="418"/>
        <source>&amp;Check clients every</source>
        <translation type="finished">Gwirio cleientiaid bob</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="469"/>
        <source>Use &amp;relative mouse moves</source>
        <translation type="finished">Defnyddio symudiadau llygoden perthynol</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="479"/>
        <source>S&amp;ynchronize screen savers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="489"/>
        <source>Don't take &amp;foreground window on Windows servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="512"/>
        <source>&amp;Dead corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="521"/>
        <source>To&amp;p-left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="528"/>
        <source>Top-rig&amp;ht</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="535"/>
        <source>&amp;Bottom-left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="542"/>
        <source>Bottom-ri&amp;ght</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="564"/>
        <source>Cor&amp;ner Size:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/SettingsDialog.cpp" line="62"/>
        <source>Encryption password must not be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="121"/>
        <source>Save log file to...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialogBase</name>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="14"/>
        <source>Settings</source>
        <translation type="finished">Gosodiadau</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="165"/>
        <source>&amp;Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="177"/>
        <source>Sc&amp;reen name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="194"/>
        <source>P&amp;ort:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="223"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="26"/>
        <source>&amp;Start Synergy after logging in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="33"/>
        <source>&amp;Automatically start server/client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="40"/>
        <source>&amp;Hide when server/client starts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="273"/>
        <source>Logging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="240"/>
        <source>&amp;Process mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="251"/>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="256"/>
        <source>Desktop (legacy)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="291"/>
        <source>&amp;Logging level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="340"/>
        <source>Log to file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="357"/>
        <source>Browse...</source>
        <translation type="finished">Pori...</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="302"/>
        <source>Error</source>
        <translation type="finished">Gwall</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="20"/>
        <source>&amp;Graphical interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="55"/>
        <source>&amp;Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="82"/>
        <source>&amp;Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="97"/>
        <source>&amp;Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="142"/>
        <source>Pass&amp;word:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="307"/>
        <source>Warning</source>
        <translation type="finished">Rhybudd</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="312"/>
        <source>Note</source>
        <translation type="finished">Nodyn</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="317"/>
        <source>Info</source>
        <translation type="finished">Gwybodaeth</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="322"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="327"/>
        <source>Debug1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="332"/>
        <source>Debug2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SetupWizard</name>
    <message>
        <location filename="src/SetupWizard.cpp" line="64"/>
        <source>Setup Synergy</source>
        <translation type="finished">Gosod fyny Synergy</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="74"/>
        <source>Please select an option.</source>
        <translation type="finished">Dewiswch.</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="84"/>
        <source>Encryption mode required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="93"/>
        <source>Encryption password required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="100"/>
        <source>Encryption password and confirmation do not match.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SetupWizardBase</name>
    <message>
        <location filename="res/SetupWizardBase.ui" line="20"/>
        <source>Setup Synergy</source>
        <translation type="finished">Gosod fyny Synergy</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="24"/>
        <source>Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="33"/>
        <source>Thanks for installing Synergy!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="108"/>
        <source>Synergy lets you easily share your mouse and keyboard between multiple computers on your desk, and it's Free and Open Source. Just move your mouse off the edge of one computer's screen on to another. You can even share all of your clipboards. All you need is a network connection. Synergy is cross-platform (works on Windows, Mac OS X and Linux).</source>
        <translation type="finished">Mae Synergy yn gadael i chi rhannu eich llygoden a'r bysellfwrdd yn hawdd rhwng nifer o gyfrifiaduron ar eich desg, ac mae'n rhad ac am ddim a Ffynhonnell Agored. Dyna gyd sydd angen yw symud eich llygoden dros ymyl sgrîn un cyfrifiadur i un arall. Gallwch hyd yn oed rannu eich holl clipfyrddau. Y cyfan sydd ei angen yw cysylltiad rhwydwaith. Mae Synergy yn draws-lwyfan (mae'n gweithio ar Windows, Mac OS X a Linux).</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="125"/>
        <source>Server or Client?</source>
        <translation type="finished">Gweinydd neu Gleient?</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="140"/>
        <source>&amp;Server (new setup)</source>
        <translation type="finished">Gweinydd (gosodiad newydd)</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="153"/>
        <source>This is the first computer you are configuring. Your keyboard and mouse are connected to this computer. This will allow you to move your mouse over to another computer's screen. There can only be one server in your setup.</source>
        <translation type="finished">Dyma'r cyfrifiadur cynta rydych yn gyflunio. Mae eich bysellfwrdd a llygoden wedi ei gysylltu i'r cyfrifiadur yma. Fe fydd hyn yn eich caniatáu i symud eich llygoden drosodd i sgrîn cyfrifiadur arall. Dim ond un gweinydd all fod yn eich gosodiad.</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="185"/>
        <source>&amp;Client (add to setup)</source>
        <translation type="finished">Cleient (ychwanegu i'r gosodiad)</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="198"/>
        <source>You have already set up a server. This is a computer you wish to control using the server's keyboard and mouse. There can be many clients in your setup.</source>
        <oldsource>You have already set up a server. This a computer you wish to control using the server's keyboard and mouse. There can be many clients in your setup.</oldsource>
        <translation type="finished">Rydych wedi gosod gweinydd fyny yn barod. Dyma'r cyfrifiadur rydych am reoli gyda bysellfwrdd a llygoden y gweinydd. Fe all fod amryw o gleientiaid yn eich gosodiad.</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="231"/>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="237"/>
        <source>Network traffic can be easily monitored. Using encryption can reduce the risk that sensitive information will be revealed to others (for example, passwords).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="263"/>
        <source>Choose a random encryption mode. The mode must be the same on both the client and server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="308"/>
        <source>&amp;Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="391"/>
        <source>A longer password will provide stronger encryption. It is a good idea to use 20 characters or more.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="415"/>
        <source>&amp;Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="474"/>
        <source>&amp;Confirm:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionChecker</name>
    <message>
        <location filename="src/VersionChecker.cpp" line="102"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>